'use strict';

/**
 * /user/docs/letter.txt'
 */

module.exports = ['\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\\\user\\docs\\Letter.txt'];